#!/usr/bin/env Rscript

library(sf)
library(dplyr)
library(giscoR)
library(ggplot2)
library(sp)

# Get command line arguments (the CSV file path will be passed as an argument)
args <- commandArgs(trailingOnly = TRUE)
csv_file <- args[1]

df <- read.csv(csv_file)

# Get Catalunya
catalunya <- gisco_get_nuts(country = "ES", nuts_level = 2) %>%
  filter(NUTS_ID == "ES51") %>%
  select(geometry)

df$id_x <- df$id_x*100
df$id_y <- df$id_y*100


sf <- st_as_sf(df, coords = c('id_x', 'id_y'), crs = 3857)

# head(sf)
# st_crs(sf)

sf <- st_transform(sf, crs = 4326)

# st_crs(sf)
# 
# mapview::mapview(sf)

sf_catalunya <- st_intersection(sf, catalunya)
mapview::mapview(sf, zcol = 'p_ed_00_04_h')
df_catalunya <- df[df$geoid %in% sf_catalunya$geoid, ]



# Save results
output_file <- paste0("results/catalunya_", basename(csv_file))
write.csv(df_catalunya, output_file)





